To run the tests, you will need to clone the ISAdatasets repository's tests branch. You can do this by running:

```
git clone -b tests --single-branch git@github.com:ISA-tools/ISAdatasets tests/data
```